use crate::utils::prop_structs::TitleProps;
use super::super::utils::user_prefs::ThemedComponent;
use dioxus::prelude::*;

pub fn Title(cx: Scope<TitleProps>) -> Element {
    let user_prefs = cx.props.user_prefs.clone();
    let title_classes = user_prefs.get_theme_classes(ThemedComponent::Card);
    let title = cx.props.title.clone();
    let is_html = cx.props.is_html;
    cx.render(rsx!{
        div { class: "p-4 ring-4 {title_classes}",
            span { class: "flex flex-row mx-auto max-w-full justify-center text-xl text-center",
                TitleHtml { title: title, is_html: is_html, user_prefs: user_prefs }
            }
        }
    })
}

fn TitleHtml(cx: Scope<TitleProps>) -> Element {
    let title = cx.props.title.clone();
    if cx.props.is_html {
        #[cfg(any(target_family = "unix", target_family = "windows"))]
        return cx.render(rsx! {
            span { class: "flex flex-row align-middle mx-auto max-w-full justify-center",
                "{title}&nbsp;"
            }
        });
        #[cfg(target_family = "wasm")]
        return cx.render(rsx! {
            span { class: "flex flex-row align-middle mx-auto max-w-full justify-center",
                div { dangerous_inner_html: "{title}", }
            }
        });
    } else {
        return cx.render(rsx! {
            span {
                "{title}"
            }
        });
    }
}
